@@ -31,7 +31,7 @@ class Player(PlayerBase):
 			return
 		
 		if "artist" in metadata and "title" in metadata and "album" in metadata:
-			return {"artist": unicode(metadata["artist"]), "title": unicode(metadata["title"]), "album": unicode(metadata["album"]), "uri": unicode(metadata["uri"])}
+			return {"artist": utf8(metadata["artist"]), "title": utf8(metadata["title"]), "album": utf8(metadata["album"]), "uri": utf8(metadata["uri"])}
 	
 	def is_playing(self):
 		try:
