@@ -31,9 +31,9 @@ class Player(PlayerBase):
 		except:
 			return
 		
-		return {"artist": unicode(obj.get_artist()),
-				"title": unicode(obj.get_title()),
-				"album": unicode(obj.get_album()),
+		return {"artist": utf8(obj.get_artist()),
+				"title": utf8(obj.get_title()),
+				"album": utf8(obj.get_album()),
 				"uri": u""
 				}
 	
